@@ -23,8 +23,7 @@
 #' @param ind Logical - if \code{ind = TRUE}, separate density lines will be plotted for each chain. If
 #' \code{ind= FALSE}, one density line will be plotted for all chains.
 #' @section Details:
-#' \code{object} argument can be a \code{stanfit} object (\code{rstan} package), an \code{mcmc.list} object
-#' (\code{coda} package), an \code{R2jags} model object (\code{R2jags} package), or a matrix containing MCMC chains (each column representing MCMC output for a single parameter, rows representing iterations in the chain). The function automatically detects the object type and proceeds accordingly.
+#' \code{object} argument can be a \code{stanfit} object (\code{rstan} package), an \code{mcmc.list} object (\code{coda} package), an \code{R2jags} model object (\code{R2jags} package), a \code{jagsUI} model object (\code{jagsUI} package), or a matrix containing MCMC chains (each column representing MCMC output for a single parameter, rows representing iterations in the chain). The function automatically detects the object type and proceeds accordingly.
 #'
 #' Matrices for the \code{priors} argument can be generated using commands such as rnorm, rgamma, runif, etc. Distributions not supported by base R can be generated by using the appropriate packages. It is important to note that some discrepancies between MCMC samplers and R may exist regarding the parameterization of distributions - one example of this is the use of precision in JAGS but standard deviation in R for the 'second parameter' of the normal distribution. If the number of draws for each prior distribution is greater than the total number used for the density plot (\code{iter} times the number of chains), the function will use a subset of the prior draws. If the number of draws for each prior distribution is less than the total number used for the density plot, the function will resample (with replacement) from the prior to obtain the appropriate number of draws.
 #'
@@ -66,7 +65,8 @@ MCMCtrace <- function(object,
   if(typeof(object) == 'double')
   {
     warning('Input type matrix - assuming only one chain for each parameter.')
-    object2 <- coda::as.mcmc.list(coda::as.mcmc(object))
+    object1 <- coda::as.mcmc.list(coda::as.mcmc(object))
+    object2 <- MCMCchains(object1, params, excl, ISB, mcmc.list = TRUE)
   }else{
     object2 <- MCMCchains(object, params, excl, ISB, mcmc.list = TRUE)
   }
